"""
This is the "sailfish.py" module, and it provides the following functions:

1. print_lol() prints lists that may or may not include nested lists

2. open_file_as_lines() returns a list, each item of which is one line (line feed
   is removed by default) of the provided file (in turn).

"""

def print_lol(the_list, indent=False, level=0):
	'''
	This function takes a positional argument called "the_list", which is
	any Python list (of, possibly, nested lists). Each data item in the 
	provided list is (recursively) printed to the screen on its own line.

	A second argrment called "indent" is used to switch on/off the indentation
	feature.

	A third argument called "level" is used to insert tab-stops when a 
	nested list is encounted. Use the value of "level" to control how many
	tab-stops are used.
	'''
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item, indent, level+1)
		else:
			'''
			# Use this "for" loop or the following "if" statement
			for num_tab_stops in range(level):
				print("\t", end='')
			'''
			if indent==True:
				print("\t"*level, end='')
			print(each_item)


def open_file_as_lines(file, remove_linefeed=True):
	'''
	This function takes a positional argument called "file", which is the file
    to be opened. The function returns a list, each item of which is one line (line feed 
	is removed by default) of the provided file (in turn).
	'''
	
	lines = []
	
	'''	
	try:
		data_file = open(file)
		
		for each_line in data_file:
			if remove_linefeed == True:
				(each_line, extra) = each_line.split("\n", 1)
			lines.append(each_line)
		
		return lines
	
	except IOError as err:
		print("File Error: " + str(err))
	finally:
		if "data_file" in locals():
			data_file.close()
	'''

	'''
	The above try/except/finally can be simplified by using the "with" statement.
	'''
	try:
		with open(file) as data_file:
			for each_line in data_file:
				if remove_linefeed == True:
					(each_line, extra) = each_line.split("\n", 1)
				lines.append(each_line)
		
		return lines
	except IOError as err:
		print("File Error: " + str(err))
